@@ -1,8 +1,9 @@
 /* archimedes.c -- This code is a simulator for Submicron 2D Silicon/GaAs
-   Devices. It implements the Monte Carlo method and MEP model
-   for the simulation of the semiclassical Boltzmann equation for both
-   electrons and holes. It also includes the quantum effects by means 
-   of effective potential method.
+   Devices. It implements the Monte Carlo method and a simplified
+   version of MEP model for the simulation of the semiclassical
+   Boltzmann equation for both electrons and holes.
+   It also includes the quantum effects by means of effective
+   potential method.
 
    Copyright (C) 2004, 2005 Jean Michel Sellier <sellier@dmi.unict.it>
  
@@ -24,9 +25,9 @@
 
 // =================================================================
 // File Name : mainArchimedes.c
-// Version   : release 0.0.3
+// Version   : release 0.0.5
 // Date of Creation : 07 Dec.2003, Paris, France, Jean Michel Sellier
-// Last Revision : 16 Mar.2005, Siracusa, Italy, Jean Michel Sellier.
+// Last Revision : 07 Apr.2005, Siracusa, Italy, Jean Michel Sellier.
 // System of Measure : M.K.S.C. System
 // =================================================================
 
@@ -65,6 +66,7 @@
 #define MESHFORMAT 1 // output file in Mesh format
 #define SILICON 0 // flag for Silicon material
 #define GAAS 1 // flag for GaAs material
+#define NUMSIO2 2 // maximum number of SiO2 interfaces
 
 // ===============================
 #include "constants.h"
@@ -82,6 +84,8 @@ int nx,ny;
 int ISEED,NP1,INUM,IV;
 int c,Model_Number,File_Format,Material,Quantum_Flag;
 int leid_flag;
+int SIO2_UP_FLAG;
+int SIO2_DOWN_FLAG;
 
 // All "real"'s here...
 real u2d[NXM+1][NYM+1][MN3+1];
@@ -113,6 +117,10 @@ real fx2d[NXM+1][NYM+1][MN3+1];
 real gy2d[NXM+1][NYM+1][MN3+1];
 real c11[7],c12[7],c21[7],c22[7];
 real u[7],f[7],g[7],cw[7];
+real SIO2_INI[NUMSIO2],SIO2_FIN[NUMSIO2];
+real SIO2_POT[NUMSIO2];
+real SIO2_THICKNESS[NUMSIO2];
+real SIO2[NUMSIO2][NXM+1][NYM+1];
 
 // All structures here...
 time_t binarytime;
@@ -197,7 +205,7 @@ Report bugs to sellier@dmi.unict.it\n");
   if (v)
     {
       /* Print version number.  */
-      printf("archimedes - GNU archimedes 0.0.2\n");
+      printf("archimedes - GNU archimedes 0.0.5\n");
       /* xgettext: no-wrap */
       printf("\n");
       printf("\
@@ -207,7 +215,7 @@ PARTICULAR PURPOSE.\n\
 You may redistribute copies of GNU %s under the terms\n\
 of the GNU General Public License.\n\
 For more information about these matters, see the file named COPYING.\n",
-              "2004","Archimedes");
+              "2004, 2005","Archimedes");
       exit (0);
     }
   else if (z){
@@ -225,6 +233,7 @@ For more information about these matters, see the file named COPYING.\n",
      memset(&u2d,0,sizeof(u2d));
      memset(&E,0,sizeof(E));
      memset(&EDGE,0,sizeof(EDGE));
+     memset(&SIO2,0,sizeof(SIO2));
 
 // Read the geometrical and physical description of the MESFET
 // ===========================================================
