@@ -1,4 +1,4 @@
-/* readinputfile.h -- This file is part of Archimedes release 0.0.3.
+/* readinputfile.h -- This file is part of Archimedes release 0.0.5.
    Archimedes is a simulator for Submicron 2D Silicon/GaAs
    Devices. It implements the Monte Carlo method and Hybrid MEP model
    for the simulation of the semiclassical Boltzmann equation for both
@@ -25,13 +25,13 @@
 
 // ######################################################
 // Created on 10 sep.2004, Siracusa, J.M.Sellier
-// Last modif. : 16 mar.2005, Siracusa, J.M.Sellier
+// Last modif. : 07 apr.2005, Siracusa, J.M.Sellier
 // ######################################################
 
 // Read the geometrical and physical description of the device.
 // The input file is interpreted as in a script language.
 // For the syntax of the commands of this language see
-// the manual GNU Archimedes release 0.0.3
+// the manual GNU Archimedes release 0.0.5
 
 void
 Read_Input_File(void)
@@ -74,6 +74,8 @@ Read_Input_File(void)
  SAVEALWAYS=0; // we don't save at each step by default
  File_Format=GNUPLOTFORMAT; // output file in mesh format
  leid_flag=0;
+ SIO2_UP_FLAG=0; // No upper SiO2
+ SIO2_DOWN_FLAG=0; // No lower SiO2
 // =====================
 
 // Reading the input file
@@ -206,6 +208,65 @@ Processing the input file\n\
     }
     printf("FINAL TIME = %g ---> Ok\n",TF);
   }
+// Setting the Silicon Oxyde interface
+  else if(strcmp(s,"OXYDE")==0){
+    fscanf(fp,"%s",s);
+    if(strcmp(s,"UP")==0){
+      SIO2_UP_FLAG=1;
+      fscanf(fp,"%Lg",&num);
+      SIO2_INI[0]=num;
+      if(num<0.){
+        printf("%s: not valid upper SiO2 initial position\n",progname);
+        exit(EXIT_FAILURE);
+      }
+      fscanf(fp,"%Lg",&num);
+      SIO2_FIN[0]=num;
+      if(num<=SIO2_INI[0] || num>LX){
+        printf("%s: not valid upper SiO2 final position\n",progname);
+        exit(EXIT_FAILURE);
+      }
+      fscanf(fp,"%Lg",&num);
+      if(num<=0.){
+        printf("%s: not valid upper SiO2 thickness\n",progname);
+        exit(EXIT_FAILURE);
+      }
+      SIO2_THICKNESS[0]=num;
+      fscanf(fp,"%Lg",&num);
+      SIO2_POT[0]=num;
+      printf("OXYDE ---> UP %g %g %g %g\n",
+              SIO2_INI[0],SIO2_FIN[0],SIO2_THICKNESS[0],SIO2_POT[0]);
+    }
+    else if(strcmp(s,"DOWN")==0){
+      SIO2_DOWN_FLAG=1;
+      fscanf(fp,"%Lg",&num);
+      SIO2_INI[1]=num;
+      if(num<0.){
+        printf("%s: not valid lower SiO2 initial position\n",progname);
+        exit(EXIT_FAILURE);
+      }
+      fscanf(fp,"%Lg",&num);
+      SIO2_FIN[1]=num;
+      if(num<=SIO2_INI[1] || num>LX){
+        printf("%s: not valid lower SiO2 final position\n",progname);
+        exit(EXIT_FAILURE);
+      }
+      fscanf(fp,"%Lg",&num);
+      if(num<=0.){
+        printf("%s: not valid lower SiO2 thickness\n",progname);
+        exit(EXIT_FAILURE);
+      }
+      SIO2_THICKNESS[1]=num;
+      fscanf(fp,"%Lg",&num);
+      SIO2_POT[1]=num;
+      printf("OXYDE ---> DOWN %g %g %g %g\n",
+              SIO2_INI[1],SIO2_FIN[1],SIO2_THICKNESS[1],SIO2_POT[1]);
+    }
+    else {
+      printf("%s: not valid final time\n",progname);
+      exit(EXIT_FAILURE);
+    }
+    printf("FINAL TIME = %g ---> Ok\n",TF);
+  }
 // setting the energy relaxation time
   else if(strcmp(s,"TAUW")==0){
     fscanf(fp,"%Lg",&num);
