@@ -1,7 +1,7 @@
 /* saveoutput2dholemeshformat.h --
-   This file is part of Archimedes release 0.0.1.
-   Archimedes is a simulator for Submicron 2D Silicon
-   Devices. It implements the Monte Carlo method
+   This file is part of Archimedes release 0.0.3.
+   Archimedes is a simulator for Submicron 2D Silicon/GaAs
+   Devices. It implements the Monte Carlo method and MEP model
    for the simulation of the semiclassical Boltzmann equation for both
    electrons and holes. It also includes the quantum effects by means 
    of effective potential method.
@@ -26,7 +26,7 @@
 
 // ######################################################
 // Created on 30 Apr.2004, Siracusa, J.M.Sellier
-// Last modif. : 02 Oct.2004, Siracusa, J.M.Sellier
+// Last modif. : 05 Mar.2005, Siracusa, J.M.Sellier
 // ######################################################
 
 // Here we save all the macroscopic variables 
@@ -39,7 +39,7 @@
 // of the mesh. This is a very diffused format
 // in the scientifical computing comunity.
 // For more information about this format see 
-// the manual of GNU archimedes release 0.0.1
+// the manual of GNU archimedes release 0.0.3
 
 void
 SaveOutput2DHole_MeshFormat(int je)
@@ -154,16 +154,16 @@ SaveOutput2DHole_MeshFormat(int je)
 // ==============================
    for(j=1;j<=ny;j++)
     for(i=1;i<=nx;i++)
-       fprintf(fp,"%g\n",h2d[i][j][1]);
+       fprintf(fp,"%g\n",h2d[i+2][j+2][1]);
    for(j=1;j<=ny;j++)
     for(i=1;i<=nx;i++)
-       fprintf(up,"%g\n",h2d[i][j][2]/(h2d[i][j][1]+SMALL));
+       fprintf(up,"%g\n",h2d[i+2][j+2][2]/h2d[i+2][j+2][1]);
    for(j=1;j<=ny;j++)
     for(i=1;i<=nx;i++)
-       fprintf(vp,"%g\n",h2d[i][j][3]/(h2d[i][j][1]+SMALL));
+       fprintf(vp,"%g\n",h2d[i+2][j+2][3]/h2d[i+2][j+2][1]);
    for(j=1;j<=ny;j++)
     for(i=1;i<=nx;i++)
-       fprintf(ep,"%g\n",h2d[i][j][4]/(h2d[i][j][1]+SMALL)); //energy (eV)
+       fprintf(ep,"%g\n",h2d[i+2][j+2][4]/h2d[i+2][j+2][1]/Q); //energy (eV)
    for(j=1;j<=ny;j++)
      for(i=1;i<=nx;i++)
        fprintf(Qp,"%g\n",u2d[i][j][0]);
